## 0.9.2.20250328 (2025-03-28)

Complete stubs for `commonmark` (#13724)

## 0.9.2.20250326 (2025-03-26)

Improve stubs for `commonmark` (#13681)

## 0.9.2.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

## 0.9.2.4 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 0.9.2.3 (2023-05-10)

Add `partial_stub` metadata field (#10157)

## 0.9.2.2 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 0.9.2.1 (2023-01-18)

Replace `Any` with `Incomplete` in many places (#9558)

## 0.9.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

